@@ -1,6 +1,6 @@
 # 
 # namcap rules - extravars
-# Copyright (C) 2003-2007 Jesse Young <jesseyoung@gmail.com>
+# Copyright (C) 2003-2009 Jesse Young <jesseyoung@gmail.com>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ class package:
 				print varname
 				if varname not in stdvars:
 					if not varname.startswith('_'):
-						ret[1].append("Non standard variable '" + varname + "' doesn't start with an underscore")
+						ret[1].append(("extra-var-begins-without-underscore %s", varname))
 		return ret
 	def type(self):
 		return "pkgbuild"
