@@ -1,6 +1,6 @@
 #
 # namcap rules - infodirectory
-# Copyright (C) 2008 Allan McRae <allan@archlinux.org>
+# Copyright (C) 2008-2009 Allan McRae <allan@archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class package:
 		ret = [[],[],[]]
 		for i in tar.getnames():
 			if i == "usr/share/info/dir":
-				ret[0].append("Info directory file (" + i + ") needs removed.")
+				ret[0].append(("info-dir-file-present %s", i))
 		return ret
 	def type(self):
 		return "tarball"
