@@ -1,6 +1,6 @@
 # 
 # namcap rules - libtool
-# Copyright (C) 2005-2007 Simo Leone <simo@archlinux.org>
+# Copyright (C) 2005-2009 Simo Leone <simo@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class package:
 		ret = [[],[],[]]
 		for i in tar.getnames():
 			if re.search('\.la$',i) != None:
-				ret[1].append("File ("+i+") is a libtool file.")
+				ret[1].append(("libtool-file-present %s", i))
 		return ret
 	def type(self):
 		return "tarball"
