@@ -1,6 +1,6 @@
 # 
 # namcap rules - scrollkeeper
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ class package:
 		for i in tar.getnames():
 			n = scroll.search(i)
 			if n != None:
-				ret[0].append("Scrollkeeper directory exists (" + i + ").  Remember to not run scrollkeeper till post_{install,upgrade,remove}.")
+				ret[0].append(("scrollkeeper-dir-exists %s", i))
 		return ret
 	def type(self):
 		return "tarball"
